/*******************************************************************************
* File Name: N.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_N_H) /* Pins N_H */
#define CY_PINS_N_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "N_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 N__PORT == 15 && ((N__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    N_Write(uint8 value);
void    N_SetDriveMode(uint8 mode);
uint8   N_ReadDataReg(void);
uint8   N_Read(void);
void    N_SetInterruptMode(uint16 position, uint16 mode);
uint8   N_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the N_SetDriveMode() function.
     *  @{
     */
        #define N_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define N_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define N_DM_RES_UP          PIN_DM_RES_UP
        #define N_DM_RES_DWN         PIN_DM_RES_DWN
        #define N_DM_OD_LO           PIN_DM_OD_LO
        #define N_DM_OD_HI           PIN_DM_OD_HI
        #define N_DM_STRONG          PIN_DM_STRONG
        #define N_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define N_MASK               N__MASK
#define N_SHIFT              N__SHIFT
#define N_WIDTH              1u

/* Interrupt constants */
#if defined(N__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in N_SetInterruptMode() function.
     *  @{
     */
        #define N_INTR_NONE      (uint16)(0x0000u)
        #define N_INTR_RISING    (uint16)(0x0001u)
        #define N_INTR_FALLING   (uint16)(0x0002u)
        #define N_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define N_INTR_MASK      (0x01u) 
#endif /* (N__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define N_PS                     (* (reg8 *) N__PS)
/* Data Register */
#define N_DR                     (* (reg8 *) N__DR)
/* Port Number */
#define N_PRT_NUM                (* (reg8 *) N__PRT) 
/* Connect to Analog Globals */                                                  
#define N_AG                     (* (reg8 *) N__AG)                       
/* Analog MUX bux enable */
#define N_AMUX                   (* (reg8 *) N__AMUX) 
/* Bidirectional Enable */                                                        
#define N_BIE                    (* (reg8 *) N__BIE)
/* Bit-mask for Aliased Register Access */
#define N_BIT_MASK               (* (reg8 *) N__BIT_MASK)
/* Bypass Enable */
#define N_BYP                    (* (reg8 *) N__BYP)
/* Port wide control signals */                                                   
#define N_CTL                    (* (reg8 *) N__CTL)
/* Drive Modes */
#define N_DM0                    (* (reg8 *) N__DM0) 
#define N_DM1                    (* (reg8 *) N__DM1)
#define N_DM2                    (* (reg8 *) N__DM2) 
/* Input Buffer Disable Override */
#define N_INP_DIS                (* (reg8 *) N__INP_DIS)
/* LCD Common or Segment Drive */
#define N_LCD_COM_SEG            (* (reg8 *) N__LCD_COM_SEG)
/* Enable Segment LCD */
#define N_LCD_EN                 (* (reg8 *) N__LCD_EN)
/* Slew Rate Control */
#define N_SLW                    (* (reg8 *) N__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define N_PRTDSI__CAPS_SEL       (* (reg8 *) N__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define N_PRTDSI__DBL_SYNC_IN    (* (reg8 *) N__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define N_PRTDSI__OE_SEL0        (* (reg8 *) N__PRTDSI__OE_SEL0) 
#define N_PRTDSI__OE_SEL1        (* (reg8 *) N__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define N_PRTDSI__OUT_SEL0       (* (reg8 *) N__PRTDSI__OUT_SEL0) 
#define N_PRTDSI__OUT_SEL1       (* (reg8 *) N__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define N_PRTDSI__SYNC_OUT       (* (reg8 *) N__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(N__SIO_CFG)
    #define N_SIO_HYST_EN        (* (reg8 *) N__SIO_HYST_EN)
    #define N_SIO_REG_HIFREQ     (* (reg8 *) N__SIO_REG_HIFREQ)
    #define N_SIO_CFG            (* (reg8 *) N__SIO_CFG)
    #define N_SIO_DIFF           (* (reg8 *) N__SIO_DIFF)
#endif /* (N__SIO_CFG) */

/* Interrupt Registers */
#if defined(N__INTSTAT)
    #define N_INTSTAT            (* (reg8 *) N__INTSTAT)
    #define N_SNAP               (* (reg8 *) N__SNAP)
    
	#define N_0_INTTYPE_REG 		(* (reg8 *) N__0__INTTYPE)
#endif /* (N__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_N_H */


/* [] END OF FILE */
